@@ -940,9 +940,17 @@ class PluggableAuthService(Folder, Cacheable):
         """ What objects can be put in here?
         """
         import Products
+        meta_types = Products.meta_types
         allowed_types = tuple(MultiPlugins) + (RAMCacheManager.meta_type,)
 
-        return [x for x in Products.meta_types if x['name'] in allowed_types]
+        meta_types = [x for x in meta_types if x['name'] in allowed_types]
+        dlg_type = 'zmi_show_add_dialog'
+
+        for mt in meta_types:
+            want_modal = getattr(mt.get('instance', None), dlg_type, True)
+            mt[dlg_type] = 'modal' if want_modal else ''
+
+        return meta_types
 
     @security.private
     def manage_beforeDelete(self, item, container):
@@ -976,7 +984,7 @@ class PluggableAuthService(Folder, Cacheable):
         resp._unauthorized = self._unauthorized
         resp._has_challenged = False
 
-    @security.public
+    @security.private
     def applyTransform(self, value):
         """ Transform for login name.
 
@@ -1024,7 +1032,7 @@ class PluggableAuthService(Folder, Cacheable):
                          'Updating existing login names.', orig_value, value)
             self.updateAllLoginNames()
 
-    @security.public
+    @security.private
     def lower(self, value):
         """ Transform for login name.
 
@@ -1034,7 +1042,7 @@ class PluggableAuthService(Folder, Cacheable):
         """
         return value.strip().lower()
 
-    @security.public
+    @security.private
     def upper(self, value):
         """ Transform for login name.
 
